vrchat_dart library

Classes

AccountDeletionLog
AddFavoriteRequest
AddGroupGalleryImageRequest
AdminAssetBundle
AdminUnityPackage
Agreement
AgreementRequest
AgreementStatus
APIConfig
APIConfigAccessLogsUrls
APIConfigAnnouncement
APIConfigAudioConfig
APIConfigAvatarPerfLimiter
APIConfigConstants
APIConfigConstantsGROUPS
APIConfigConstantsINSTANCE
APIConfigConstantsINSTANCEPOPULATIONBRACKETS
APIConfigConstantsINSTANCEPOPULATIONBRACKETSCROWDED
APIConfigConstantsINSTANCEPOPULATIONBRACKETSFEW
APIConfigConstantsINSTANCEPOPULATIONBRACKETSMANY
APIConfigConstantsLANGUAGE
APIConfigDownloadURLList
APIConfigEvents
APIConfigIosVersion
APIConfigMinSupportedClientBuildNumber
APIConfigOfflineAnalysis
APIHealth
ApiKeyAuthInterceptor
AuthenticationApi
AuthResponse
A response from the auth API
Avatar
AvatarModeration
AvatarModerationCreated
AvatarPerformance
AvatarPublishedListingsInner
AvatarsApi
AvatarStyle
AvatarStyles
AvatarUnityPackageUrlObject
Badge
Balance
BanGroupMemberRequest
BasicAuthInfo
BasicAuthInterceptor
BearerAuthInterceptor
BoopRequest
CalendarApi
CalendarEvent
CalendarEventDiscovery
CalendarEventRecurrence
CalendarEventRecurrenceEnd
CalendarEventUserInterest
ChangeUserTagsRequest
ChangeWorldTagsRequest
CreateAvatarModerationRequest
CreateAvatarRequest
CreateCalendarEventRequest
CreateFileRequest
CreateFileVersionRequest
CreateGroupAnnouncementRequest
CreateGroupGalleryRequest
CreateGroupInviteRequest
CreateGroupPostRequest
CreateGroupRequest
CreateGroupRoleRequest
CreateInstanceRequest
CreateJamSubmissionRequest
CreateListingRequest
CreateProductRequest
CreatePropRequest
CreateWorldRequest
CurrentUser
CurrentUserPlatformHistoryInner
CurrentUserPresence
DeclineGroupInviteRequest
Disable2FAResult
DiscordDetails
DynamicContentRow
EarningsMetrics
EarningsMetricsTotals
EconomyAccount
EconomyApi
EconomyBalances
EconomyPayout
EconomyPayoutEligibility
EconomyPayoutList
EconomyPayoutStatus
EquipInventoryItemRequest
Error
ErrorEvent
An error message returned from the server
Favorite
FavoritedWorld
FavoriteGroup
FavoriteGroupLimits
FavoriteLimits
FavoritesApi
Feedback
File
FileAnalysis
FileAnalysisAvatarStats
FileData
FilesApi
FileUploadURL
FileVersion
FileVersionUploadStatus
FinishFileDataUploadRequest
FollowCalendarEventRequest
FriendActiveEvent
A FriendActiveEvent is sent when one of the user’s friends is active on the website.
FriendAddEvent
A FriendAddEvent is sent when the user has either accepted a friend request, or has had one of their friend requests accepted.
FriendDeleteEvent
A FriendDeleteEvent is sent when the user has either been removed as a friend, or has removed someone else as a friend.
FriendEvent
Base class for FriendEvents
FriendEventWithUser
Base class for FriendEvents that contain a user object
FriendLocationEvent
A FriendLocationEvent is sent when one of the user’s friends has changed instances. Note that the world field will be an empty object when the friend is on orange/red, or is in a private world.
FriendOfflineEvent
A FriendOfflineEvent is sent when one of the user’s friends has gone offline.
FriendOnlineEvent
A FriendOnlineEvent is sent when one of the user’s friends has gone online in-game. Note that the world field will be an empty object when the friend is on orange/red, or is in a private world.
FriendsApi
FriendStatus
FriendUpdateEvent
A FriendUpdateEvent is sent when something about one of the user’s friends profile has changed.
GetGroupPosts200Response
GetUserGroupInstances200Response
Group
GroupAnnouncement
GroupAuditLogEntry
GroupGallery
GroupGalleryFileOrder
GroupGalleryFileOrderRequest
GroupGalleryImage
GroupInstance
GroupMember
GroupMemberLimitedUser
GroupMyMember
GroupPermission
GroupPost
GroupRole
GroupRoleTemplateValues
GroupRoleTemplateValuesRoles
GroupsApi
GroupTransferable
GroupTransferableRequirements
InfoPush
InfoPushData
InfoPushDataArticle
InfoPushDataArticleContent
InfoPushDataClickable
Instance
InstanceContentSettings
InstancePlatforms
InstancesApi
InstanceShortNameResponse
Inventory
InventoryApi
InventoryConsumptionResults
InventoryDefaultAttributesValue
InventoryDefaultAttributesValueValidator
InventoryDrop
InventoryItem
InventoryMetadata
InventoryNotificationDetails
InventorySpawn
InventoryTemplate
InventoryUserAttributes
InviteApi
InviteMessage
InviteRequest
InviteResponse
Jam
JamsApi
JamStateChangeDates
JamSubmission
JoinGroupRequest
License
LicenseGroup
LimitedGroup
LimitedUnityPackage
LimitedUser
A combination of LimitedUserInstance, LimitedUserFriend, and LimitedUserSearch
LimitedUserFriend
LimitedUserGroups
LimitedUserInstance
LimitedUserSearch
LimitedWorld
MiscellaneousApi
ModerateUserRequest
ModerationReport
MutualFriend
Mutuals
Notification
NotificationClearEvent
A NotificationClearEvent is sent when the client should clear all notifications.
NotificationDetailInvite
NotificationDetailInviteResponse
NotificationDetailRequestInvite
NotificationDetailRequestInviteResponse
NotificationDetailVoteToKick
NotificationEvent
Base class for NotificationEvents
NotificationHideEvent
A NotificationHideEvent is sent when the client should hide a notification.
NotificationReceivedEvent
A NotificationReceivedEvent carries a Notification object, and are used by Invites, Friend Requests and other in-game notifications.
NotificationResponseEvent
The NotificationResponseEvent is used to respond to a previously sent event. It carries an ID of the response notification responseId, whereby the data is required to be fetched from the API. It also carries notificationId to indicate which notification this is a response to.
NotificationsApi
NotificationSeenEvent
A NotificationSeenEvent is sent when the client should mark a specific notification as seen.
NotificationV2
NotificationV2DetailsBoop
NotificationV2Response
OAuthInterceptor
OkStatus
OkStatus2
PaginatedCalendarEventList
PaginatedGroupAuditLogEntryList
PaginatedModerationReportList
PastDisplayName
Pending2FAResult
PerformanceLimiterInfo
Permission
PermissionData
PlatformBuildInfo
PlayerModeration
PlayermoderationApi
Print
PrintFiles
PrintsApi
PrivateProfile
PrivateProfileActivity
Product
ProductListing
ProductListingVariant
ProductPurchase
ProductPurchaseHistory
ProductPurchaseProduct
ProductPurchasePurchaseContext
ProductPurchaseRecord
ProfileRepresentedGroup
Prop
PropPublishStatus
PropsApi
PropUnityPackage
PublicProfile
PurchaseContextData
PurchaseProductListingRequest
RegisterUserAccountRequest
ReportCategory
ReportReason
RepresentedGroup
RequestInviteRequest
RespondGroupJoinRequest
RespondNotificationV2Request
Response
RewardBadge
RewardRedemption
RewardRedemptionData
RewardRedemptionRequest
RewardRedemptionResult
SearchGroupMembers200Response
SellerEligibility
SentNotification
ServiceQueueStats
ServiceStatus
ShareInventoryItemDirectRequest
Store
StoreContext
StoreShelf
StreamedCurrentUser
A user object representing the signed in user streamed from the VRChat websocket connection
SubmitModerationReportRequest
SubmitModerationReportRequestDetails
Subscription
Success
SuccessFlag
TiliaKyc
TiliaStatus
TiliaTOS
TokenBundle
Transaction
TransactionAgreement
TransactionSteamInfo
TransactionSteamWalletInfo
TransferGroupRequest
TutorialStatus
TwoFactorAuthCode
TwoFactorEmailCode
TwoFactorRecoveryCodes
TwoFactorRecoveryCodesOtpInner
UnityPackage
UnknownEvent
These shouldn't happen unless VRChat adds more events
UpdateAssetReviewNotesRequest
UpdateAvatarRequest
UpdateCalendarEventRequest
UpdateFavoriteGroupRequest
UpdateGroupGalleryRequest
UpdateGroupMemberRequest
UpdateGroupRepresentationRequest
UpdateGroupRequest
UpdateGroupRoleRequest
UpdateInventoryItemRequest
UpdateInviteMessageRequest
UpdateListingRequest
UpdateProductRequest
UpdatePropRequest
UpdateTiliaTOSRequest
UpdateUserBadgeRequest
UpdateUserNoteRequest
UpdateUserRequest
UpdateWorldRequest
User
UserCreditsEligible
UserEvent
Base class for UserEvents
UserExists
UserLocationEvent
A UserLocationEvent is sent when the user has changed instances.
UserNote
UserNoteTargetUser
UsersApi
UserSubscription
UserSubscriptionEligible
UserUpdateEvent
A UserUpdateEvent is sent when something regarding the user has been updated. Note that the user object is not a LimitedUser object, even though it has similarities. It’s missing developerType, friendKey, isFriend, lastPlatform and location. It also has an extra currentAvatar field.
Verify2FAEmailCodeResult
Verify2FAResult
VerifyAuthTokenResult
VrcError
An error returned from the VRChat API
VrchatDart
VrchatDart
VrchatDartGenerated
VrchatUserAgent
A user agent that satisfies the VRChat guidelines
VrcStreaming
Streaming for data updates from the VRChat websocket API
VrcStreamingEvent
Base class for VrcStreamingEvents
World
WorldMetadata
WorldPublishStatus
WorldsApi

Enums

AgeVerificationStatus
verified is obsolete. User who have verified and are 18+ can switch to plus18 status.
AgreementCode
The type of agreement.
AvatarModerationType
CalendarDayOfWeek
The day of the week, used for recurring events.
CalendarEventAccess
Who the event is for
CalendarEventCategory
The activity intended to take place at an event
CalendarEventDiscoveryInclusion
CalendarEventDiscoveryScope
CalendarEventFrequency
The time unit used to specify how often a recurring event occurs.
CalendarEventOccurrenceKind
How an event occurs or recurs. "single" is a standalone event, "series" is a parent specification of a recurring series, and "occurrence" is an individual event in a series.
CalendarEventPlatform
CalendarEventRecurrenceEndType
How a recurring event stops being scheduled
ContentFilter
Flags for content filtering
DeveloperType
"none" User is a normal user "trusted" Unknown "internal" Is a VRChat Developer "moderator" Is a VRChat Moderator Staff can hide their developerType at will.
FavoriteGroupVisibility
FavoriteType
FileDataCategoryEnum
FileStatus
GroupAccessType
Group access type when the instance type is "group"
GroupJoinRequestAction
GroupJoinState
GroupMemberStatus
GroupPermissions
GroupPostVisibility
GroupPrivacy
GroupRoleTemplate
GroupSearchSort
GroupUserVisibility
ImageAnimationStyle
Animation style for images.
ImageLoopStyle
Animation looping style for images.
ImageMask
Mask shape for images.
ImagePurpose
Indication of the purpose for uploading images.
InfoPushDataClickableCommandEnum
InstanceRegion
Instance region
InstanceType
InventoryEquipSlot
InventoryFlag
InventoryItemType
InviteMessageType
LicenseAction
LicenseType
MIMEType
NotificationType
NotificationV2Type
OrderOption
OrderOptionShort
PerformanceRatings
Avatar Performance ratings.
PlayerModerationType
ProductListingType
ProductPurchaseLocationType
ProductType
Region
API/Photon region.
ReleaseStatus
SortOption
SortOptionProductPurchase
StoreType
StoreView
SubscriptionPeriod
TransactionStatus
TwoFactorAuthType
Types of two factor auth for VRChat
UserState
  • "online" User is online in VRChat * "active" User is online, but not in VRChat * "offline" User is offline Always offline when returned through getCurrentUser (/auth/user).
  • UserStatus
    Defines the User's current status, for example "ask me", "join me" or "offline. This status is a combined indicator of their online activity and privacy preference.
    VrcStreamingEventType
    Enum of all possible types of VrcStreamingEvent

    Extensions

    CurrentUserExtension on CurrentUser
    Convenience methods on CurrentUser
    LimitedUserFriendExtension on LimitedUserFriend
    Convenience methods on LimitedUserFriend
    LimitedUserInstanceExtension on LimitedUserInstance
    Convenience methods on LimitedUserInstance
    LimitedUserSearchExtension on LimitedUserSearch
    Convenience methods on LimitedUserSearch
    UserExtension on User
    Convenience methods on User
    VrcInvalidResponse on InvalidResponse
    Extension on ValidatedResponse to get the VrcError if it exists
    VrcResponseValidator on Future<Response<T>>
    Extension on Dio Response futures for validation
    VrcStreamingEventTypeExtension on VrcStreamingEventType
    Convenience methods to call on VrcStreamingEventTypes