APIConfigConstants class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

APIConfigConstants({required APIConfigConstantsGROUPS groups, required APIConfigConstantsINSTANCE instance, required APIConfigConstantsLANGUAGE language})
Returns a new APIConfigConstants instance.
APIConfigConstants.fromJson(Map<String, dynamic> json)
factory

Properties

groups APIConfigConstantsGROUPS
final
hashCode int
The hash code for this object.
no setteroverride
instance APIConfigConstantsINSTANCE
final
language APIConfigConstantsLANGUAGE
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override