CurrentUserPlatformHistoryInner class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
- CurrentUserPlatformHistoryInner({bool? isMobile, String? platform, DateTime? recorded})
- Returns a new CurrentUserPlatformHistoryInner instance.
-
CurrentUserPlatformHistoryInner.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isMobile → bool?
-
final
- platform → String?
-
This is normally
android,ios,standalonewindows,web, or the empty value ``, but also supposedly can be any random Unity version such as2019.2.4-801-Releaseor2019.2.2-772-Releaseor evenunknownplatform.final - recorded → DateTime?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override