GroupMember class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

GroupMember({String? acceptedByDisplayName, String? acceptedById, DateTime? bannedAt, DateTime? createdAt, required String groupId, bool? hasJoinedFromPurchase, required String id, bool isRepresenting = false, bool isSubscribedToAnnouncements = false, bool? isSubscribedToEventAnnouncements, required DateTime? joinedAt, required DateTime? lastPostReadAt, required List<String> mRoleIds, String? managerNotes, required GroupMemberStatus membershipStatus, required List<String> roleIds, GroupMemberLimitedUser? user, required String userId, required String visibility})
Returns a new GroupMember instance.
GroupMember.fromJson(Map<String, dynamic> json)
factory

Properties

acceptedByDisplayName String?
Only missing when explicitly fetching own user.
final
acceptedById String?
Only missing when explicitly fetching own user.
final
bannedAt DateTime?
Only missing when explicitly fetching own user.
final
createdAt DateTime?
Only missing when explicitly fetching own user.
final
groupId String
final
hashCode int
The hash code for this object.
no setteroverride
hasJoinedFromPurchase bool?
Missing when explicitly fetching own user, or when group isn't linked to a purchase.
final
id String
final
isRepresenting bool
Whether the user is representing the group. This makes the group show up above the name tag in-game.
final
isSubscribedToAnnouncements bool
final
isSubscribedToEventAnnouncements bool?
Only missing when explicitly fetching own user.
final
joinedAt DateTime?
final
lastPostReadAt DateTime?
final
managerNotes String?
Only missing when explicitly fetching own user.
final
membershipStatus GroupMemberStatus
final
mRoleIds List<String>
final
roleIds List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user GroupMemberLimitedUser?
final
userId String
A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
final
visibility String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override