ImageLoopStyle enum

Animation looping style for images.

Inheritance
Available extensions

Values

linear → const ImageLoopStyle

Animation looping style for images.

const ImageLoopStyle(r'linear')
pingpong → const ImageLoopStyle

Animation looping style for images.

const ImageLoopStyle(r'pingpong')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageLoopStyle>
A constant List of the values in this enum, in order of their declaration.