InventoryDrop class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

InventoryDrop({required String authorId, required DateTime createdAt, required DateTime? dropExpiryDate, required DateTime endDropDate, required String id, required bool isDisabled, required String name, required InventoryNotificationDetails notificationDetails, required DateTime startDropDate, required String status, required List<String> tags, required String targetGroup, required List<String> templateIds, required DateTime updatedAt})
Returns a new InventoryDrop instance.
InventoryDrop.fromJson(Map<String, dynamic> json)
factory

Properties

authorId String
A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
final
createdAt DateTime
final
dropExpiryDate DateTime?
final
endDropDate DateTime
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
isDisabled bool
final
name String
final
notificationDetails InventoryNotificationDetails
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDropDate DateTime
final
status String
final
tags List<String>
final
targetGroup String
final
templateIds List<String>
final
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override