InventoryFlag enum

Inheritance
Available extensions

Values

archivable → const InventoryFlag
const InventoryFlag(r'archivable')
cloneable → const InventoryFlag
const InventoryFlag(r'cloneable')
consumable → const InventoryFlag
const InventoryFlag(r'consumable')
equippable → const InventoryFlag
const InventoryFlag(r'equippable')
instantiatable → const InventoryFlag
const InventoryFlag(r'instantiatable')
trashable → const InventoryFlag
const InventoryFlag(r'trashable')
ugc → const InventoryFlag
const InventoryFlag(r'ugc')
unique → const InventoryFlag
const InventoryFlag(r'unique')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InventoryFlag>
A constant List of the values in this enum, in order of their declaration.