InventoryNotificationDetails class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

InventoryNotificationDetails({required String body, required String imageUrl, required String title})
Returns a new InventoryNotificationDetails instance.
InventoryNotificationDetails.fromJson(Map<String, dynamic> json)
factory

Properties

body String
final
hashCode int
The hash code for this object.
no setteroverride
imageUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override