MIMEType enum
Values
- applicationSlashGzip → const MIMEType
-
const MIMEType(r'application/gzip') - applicationSlashOctetStream → const MIMEType
-
const MIMEType(r'application/octet-stream') - applicationSlashXAvatar → const MIMEType
-
const MIMEType(r'application/x-avatar') - applicationSlashXProp → const MIMEType
-
const MIMEType(r'application/x-prop') - applicationSlashXRsyncDelta → const MIMEType
-
const MIMEType(r'application/x-rsync-delta') - applicationSlashXRsyncSignature → const MIMEType
-
const MIMEType(r'application/x-rsync-signature') - applicationSlashXWorld → const MIMEType
-
const MIMEType(r'application/x-world') - imageSlashBmp → const MIMEType
-
const MIMEType(r'image/bmp') - imageSlashGif → const MIMEType
-
const MIMEType(r'image/gif') - imageSlashJpeg → const MIMEType
-
const MIMEType(r'image/jpeg') - imageSlashJpg → const MIMEType
-
const MIMEType(r'image/jpg') - imageSlashPng → const MIMEType
-
const MIMEType(r'image/png') - imageSlashSvgxml → const MIMEType
-
const MIMEType(r'image/svg+xml') - imageSlashTiff → const MIMEType
-
const MIMEType(r'image/tiff') - imageSlashWebp → const MIMEType
-
const MIMEType(r'image/webp')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited