NotificationsApi class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
acceptFriendRequest ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Success > >
Accept Friend Request
Accept a friend request by notification `frq_` ID. Friend requests can be found using the NotificationsAPI `getNotifications` by filtering of type `friendRequest`.
acknowledgeNotificationV2 ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<NotificationV2 > >
Acknowledge NotificationV2
Acknowledge a specific notification
clearNotifications ({CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Success > >
Clear All Notifications
Clear all notifications.
deleteAllNotificationV2s ({CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Success > >
Delete All NotificationV2s
Delete all of the current user's notifications.
deleteNotification ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Notification > >
Delete Notification
Delete a notification.
deleteNotificationV2 ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Success > >
Delete NotificationV2
Delete a specific notification
getNotification ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Notification > >
Show notification
Get a notification by notification `not_` ID.
getNotifications ({String ? type , bool ? sent , bool ? hidden , String ? after , int ? n = 60 , int ? offset , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<List <Notification > > >
List Notifications
Retrieve all of the current user's notifications.
getNotificationV2 ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<NotificationV2 > >
Get NotificationV2
Get a specific notification. Appears to require admin credentials by default. Expect a 403 Forbidden error response for normal users.
getNotificationV2s ({int ? limit , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<List <NotificationV2 > > >
List NotificationV2s
Retrieve all of the current user's notifications.
markNotificationAsRead ({required String notificationId , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<Notification > >
Mark Notification As Read
Mark a notification as seen.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replyNotificationV2 ({required String notificationId , required Object body , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<NotificationV2 > >
Reply NotificationV2
Reply to a specific notification
respondNotificationV2 ({required String notificationId , required RespondNotificationV2Request respondNotificationV2Request , CancelToken? cancelToken , ValidateStatus? validateStatus , ProgressCallback? onSendProgress , ProgressCallback? onReceiveProgress })
→ Future <Response<NotificationV2 > >
Respond NotificationV2
Respond to a specific notification
toString ()
→ String
A string representation of this object.
inherited