location property

  1. @JsonKey.new(name: r'location', required: false, includeIfNull: false)
String? location
final

Represents a unique location, consisting of a world identifier and an instance identifier, or "offline" if the user is not on your friends list.

Implementation

@JsonKey(name: r'location', required: false, includeIfNull: false)
final String? location;