UnityPackage class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

UnityPackage({String? assetUrl, Object? assetUrlObject, required int assetVersion, DateTime? createdAt, required String id, String? impostorUrl, String? impostorizerVersion, PerformanceRatings? performanceRating, required String platform, String? pluginUrl, Object? pluginUrlObject, String? scanStatus, int? unitySortNumber, String unityVersion = '5.3.4p1', String? variant, String? worldSignature})
Returns a new UnityPackage instance.
UnityPackage.fromJson(Map<String, dynamic> json)
factory

Properties

assetUrl String?
final
assetUrlObject Object?
final
assetVersion int
final
createdAt DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
impostorizerVersion String?
final
impostorUrl String?
final
performanceRating PerformanceRatings?
final
platform String
This is normally android, ios, standalonewindows, web, or the empty value ``, but also supposedly can be any random Unity version such as 2019.2.4-801-Release or 2019.2.2-772-Release or even unknownplatform.
final
pluginUrl String?
final
pluginUrlObject Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanStatus String?
final
unitySortNumber int?
final
unityVersion String
final
variant String?
final
worldSignature String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override