VrchatApiGeneratorConfig class
This class is used by openapi_generator to generate the API
- Annotations
-
- @Openapi.new(alwaysRun: true, overwriteExistingFiles: true, additionalProperties: DioProperties(pubName: 'vrchat_dart_generated', pubDescription: 'The generated API used by vrchat_dart. Generated from https://github.com/vrchatapi/specification.', pubHomepage: 'https://github.com/vrchatapi/vrchatapi-dart', pubVersion: '1.5.2', dateLibrary: DioDateLibrary.core), inputSpecFile: 'https://vrchatapi.github.io/specification/openapi.yaml', generatorName: Generator.dioNext, outputDirectory: '../vrchat_dart_generated')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited