vrchat_dart
library
Classes
AccountDeletionLog
AddFavoriteRequest
AddGroupGalleryImageRequest
AdminAssetBundle
AdminUnityPackage
Agreement
AgreementRequest
AgreementStatus
APIConfig
APIConfigAccessLogsUrls
APIConfigAnnouncement
APIConfigAudioConfig
APIConfigAvatarPerfLimiter
APIConfigConstants
APIConfigConstantsGROUPS
APIConfigConstantsINSTANCE
APIConfigConstantsINSTANCEPOPULATIONBRACKETS
APIConfigConstantsINSTANCEPOPULATIONBRACKETSCROWDED
APIConfigConstantsINSTANCEPOPULATIONBRACKETSFEW
APIConfigConstantsINSTANCEPOPULATIONBRACKETSMANY
APIConfigConstantsLANGUAGE
APIConfigDownloadURLList
APIConfigEvents
APIConfigIosVersion
APIConfigMinSupportedClientBuildNumber
APIConfigOfflineAnalysis
APIHealth
ApiKeyAuthInterceptor
AuthenticationApi
AuthResponse
A response from the auth API
Avatar
AvatarModeration
AvatarModerationCreated
AvatarPerformance
AvatarPublishedListingsInner
AvatarsApi
AvatarStyle
AvatarStyles
AvatarUnityPackageUrlObject
Badge
Balance
BanGroupMemberRequest
BasicAuthInfo
BasicAuthInterceptor
BearerAuthInterceptor
BoopRequest
CalendarApi
CalendarEvent
CalendarEventDiscovery
CalendarEventRecurrence
CalendarEventRecurrenceEnd
CalendarEventUserInterest
ChangeUserTagsRequest
ChangeWorldTagsRequest
CreateAvatarModerationRequest
CreateAvatarRequest
CreateCalendarEventRequest
CreateFileRequest
CreateFileVersionRequest
CreateGroupAnnouncementRequest
CreateGroupGalleryRequest
CreateGroupInviteRequest
CreateGroupPostRequest
CreateGroupRequest
CreateGroupRoleRequest
CreateInstanceRequest
CreateJamSubmissionRequest
CreateListingRequest
CreateProductRequest
CreatePropRequest
CreateWorldRequest
CurrentUser
CurrentUserPlatformHistoryInner
CurrentUserPresence
DeclineGroupInviteRequest
Disable2FAResult
DiscordDetails
DynamicContentRow
EarningsMetrics
EarningsMetricsTotals
EconomyAccount
EconomyApi
EconomyBalances
EconomyPayout
EconomyPayoutEligibility
EconomyPayoutList
EconomyPayoutStatus
EquipInventoryItemRequest
Error
ErrorEvent
An error message returned from the server
Favorite
FavoritedWorld
FavoriteGroup
FavoriteGroupLimits
FavoriteLimits
FavoritesApi
Feedback
File
FileAnalysis
FileAnalysisAvatarStats
FileData
FilesApi
FileUploadURL
FileVersion
FileVersionUploadStatus
FinishFileDataUploadRequest
FollowCalendarEventRequest
FriendActiveEvent
A FriendActiveEvent is sent when one of the user’s friends is active on
the website.
FriendAddEvent
A FriendAddEvent is sent when the user has either accepted a friend
request, or has had one of their friend requests accepted.
FriendDeleteEvent
A FriendDeleteEvent is sent when the user has either been removed as
a friend, or has removed someone else as a friend.
FriendEvent
Base class for FriendEvent s
FriendEventWithUser
Base class for FriendEvent s that contain a user object
FriendLocationEvent
A FriendLocationEvent is sent when one of the user’s friends has changed
instances. Note that the world field will be an empty object when the
friend is on orange/red, or is in a private world.
FriendOfflineEvent
A FriendOfflineEvent is sent when one of the user’s friends has gone
offline.
FriendOnlineEvent
A FriendOnlineEvent is sent when one of the user’s friends has gone
online in-game. Note that the world field will be an empty object when the
friend is on orange/red, or is in a private world.
FriendsApi
FriendStatus
FriendUpdateEvent
A FriendUpdateEvent is sent when something about one of the user’s
friends profile has changed.
GetGroupPosts200Response
GetUserGroupInstances200Response
Group
GroupAnnouncement
GroupAuditLogEntry
GroupGallery
GroupGalleryFileOrder
GroupGalleryFileOrderRequest
GroupGalleryImage
GroupInstance
GroupMember
GroupMemberLimitedUser
GroupMyMember
GroupPermission
GroupPost
GroupRole
GroupRoleTemplateValues
GroupRoleTemplateValuesRoles
GroupsApi
GroupTransferable
GroupTransferableRequirements
InfoPush
InfoPushData
InfoPushDataArticle
InfoPushDataArticleContent
InfoPushDataClickable
Instance
InstanceContentSettings
InstancePlatforms
InstancesApi
InstanceShortNameResponse
Inventory
InventoryApi
InventoryConsumptionResults
InventoryDefaultAttributesValue
InventoryDefaultAttributesValueValidator
InventoryDrop
InventoryItem
InventoryMetadata
InventoryNotificationDetails
InventorySpawn
InventoryTemplate
InventoryUserAttributes
InviteApi
InviteMessage
InviteRequest
InviteResponse
Jam
JamsApi
JamStateChangeDates
JamSubmission
JoinGroupRequest
License
LicenseGroup
LimitedGroup
LimitedUnityPackage
LimitedUser
A combination of LimitedUserInstance , LimitedUserFriend , and LimitedUserSearch
LimitedUserFriend
LimitedUserGroups
LimitedUserInstance
LimitedUserSearch
LimitedWorld
MiscellaneousApi
ModerateUserRequest
ModerationReport
MutualFriend
Mutuals
Notification
NotificationClearEvent
A NotificationClearEvent is sent when the client should clear all notifications.
NotificationDetailInvite
NotificationDetailInviteResponse
NotificationDetailRequestInvite
NotificationDetailRequestInviteResponse
NotificationDetailVoteToKick
NotificationEvent
Base class for NotificationEvent s
NotificationHideEvent
A NotificationHideEvent is sent when the client should hide a notification.
NotificationReceivedEvent
A NotificationReceivedEvent carries a Notification object, and are
used by Invites, Friend Requests and other in-game notifications.
NotificationResponseEvent
The NotificationResponseEvent is used to respond to a previously
sent event. It carries an ID of the response notification responseId ,
whereby the data is required to be fetched from the API. It also carries
notificationId to indicate which notification this is a response to.
NotificationsApi
NotificationSeenEvent
A NotificationSeenEvent is sent when the client should mark a
specific notification as seen.
NotificationV2
NotificationV2DetailsBoop
NotificationV2Response
OAuthInterceptor
OkStatus
OkStatus2
PaginatedCalendarEventList
PaginatedGroupAuditLogEntryList
PaginatedModerationReportList
PastDisplayName
Pending2FAResult
PerformanceLimiterInfo
Permission
PermissionData
PlatformBuildInfo
PlayerModeration
PlayermoderationApi
Print
PrintFiles
PrintsApi
PrivateProfile
PrivateProfileActivity
Product
ProductListing
ProductListingVariant
ProductPurchase
ProductPurchaseHistory
ProductPurchaseProduct
ProductPurchasePurchaseContext
ProductPurchaseRecord
ProfileRepresentedGroup
Prop
PropPublishStatus
PropsApi
PropUnityPackage
PublicProfile
PurchaseContextData
PurchaseProductListingRequest
RegisterUserAccountRequest
ReportCategory
ReportReason
RepresentedGroup
RequestInviteRequest
RespondGroupJoinRequest
RespondNotificationV2Request
Response
RewardBadge
RewardRedemption
RewardRedemptionData
RewardRedemptionRequest
RewardRedemptionResult
SearchGroupMembers200Response
SellerEligibility
SentNotification
ServiceQueueStats
ServiceStatus
ShareInventoryItemDirectRequest
Store
StoreContext
StoreShelf
StreamedCurrentUser
A user object representing the signed in user streamed from the VRChat websocket connection
SubmitModerationReportRequest
SubmitModerationReportRequestDetails
Subscription
Success
SuccessFlag
TiliaKyc
TiliaStatus
TiliaTOS
TokenBundle
Transaction
TransactionAgreement
TransactionSteamInfo
TransactionSteamWalletInfo
TransferGroupRequest
TutorialStatus
TwoFactorAuthCode
TwoFactorEmailCode
TwoFactorRecoveryCodes
TwoFactorRecoveryCodesOtpInner
UnityPackage
UnknownEvent
These shouldn't happen unless VRChat adds more events
UpdateAssetReviewNotesRequest
UpdateAvatarRequest
UpdateCalendarEventRequest
UpdateFavoriteGroupRequest
UpdateGroupGalleryRequest
UpdateGroupMemberRequest
UpdateGroupRepresentationRequest
UpdateGroupRequest
UpdateGroupRoleRequest
UpdateInventoryItemRequest
UpdateInviteMessageRequest
UpdateListingRequest
UpdateProductRequest
UpdatePropRequest
UpdateTiliaTOSRequest
UpdateUserBadgeRequest
UpdateUserNoteRequest
UpdateUserRequest
UpdateWorldRequest
User
UserCreditsEligible
UserEvent
Base class for UserEvent s
UserExists
UserLocationEvent
A UserLocationEvent is sent when the user has changed instances.
UserNote
UserNoteTargetUser
UsersApi
UserSubscription
UserSubscriptionEligible
UserUpdateEvent
A UserUpdateEvent is sent when something regarding the user has been
updated. Note that the user object is not a LimitedUser object, even
though it has similarities. It’s missing developerType, friendKey,
isFriend, lastPlatform and location. It also has an extra
currentAvatar field.
Verify2FAEmailCodeResult
Verify2FAResult
VerifyAuthTokenResult
VrcError
An error returned from the VRChat API
VrchatDart
VrchatDart
VrchatDartGenerated
VrchatUserAgent
A user agent that satisfies the VRChat guidelines
VrcStreaming
Streaming for data updates from the VRChat websocket API
VrcStreamingEvent
Base class for VrcStreamingEvent s
World
WorldMetadata
WorldPublishStatus
WorldsApi