GroupRoleTemplateValues class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
-
GroupRoleTemplateValues({required List<
GroupPermissions> basePermissions, required String description, required String name, required GroupRoleTemplateValuesRoles roles}) - Returns a new GroupRoleTemplateValues instance.
-
GroupRoleTemplateValues.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
basePermissions
→ List<
GroupPermissions> -
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- roles → GroupRoleTemplateValuesRoles
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override