PermissionData class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
Properties
-
badges
→ List<
String> ? -
Badges afforded the user by this permission
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- max → int?
-
Maximum value afforded the user by this permission
final
-
maxFavoriteGroups
→ Map<
String, int> ? -
Maximum favorite groups afforded the user by this permission
final
-
maxFavoritesPerGroup
→ Map<
String, int> ? -
Maximum favorites per group afforded the user by this permission
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Tags afforded the user by this permission
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override