PrivateProfileActivity class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
-
PrivateProfileActivity({String? instanceId, String? lastActivity, String? lastLogin, String? location, String? platform, UserState? state, String? travelingToInstance, String? travelingToLocation, String? travelingToWorld, String? worldId})
-
Returns a new PrivateProfileActivity instance.
-
PrivateProfileActivity.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
instanceId
→ String?
-
InstanceID can be "offline" on User profiles if you are not friends with that user and "private" if you are friends and user is in private instance.
final
-
lastActivity
→ String?
-
Either a date-time or an empty string.
final
-
lastLogin
→ String?
-
Either a date-time or an empty string.
final
-
location
→ String?
-
Represents a unique location, consisting of a world identifier and an instance identifier, or "offline" if the user is not on your friends list.
final
-
platform
→ String?
-
This is normally
android, ios, standalonewindows, web, or the empty value ``, but also supposedly can be any random Unity version such as 2019.2.4-801-Release or 2019.2.2-772-Release or even unknownplatform.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ UserState?
-
final
-
travelingToInstance
→ String?
-
final
-
travelingToLocation
→ String?
-
final
-
travelingToWorld
→ String?
-
final
-
worldId
→ String?
-
WorldID be "offline" on User profiles if you are not friends with that user.
final