ProductPurchaseRecord class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
- ProductPurchaseRecord({required int amount, required int balance, required DateTime date, required String fromUserDisplayName, required String listingDisplayName, required ProductListingType listingType, required String platform, required String purchaseId, required int reason, required String reasonLabel, required int transactionId, required int transactionLineId})
- Returns a new ProductPurchaseRecord instance.
-
ProductPurchaseRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → int
-
final
- balance → int
-
final
- date → DateTime
-
final
- fromUserDisplayName → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- listingDisplayName → String
-
final
- listingType → ProductListingType
-
final
- platform → String
-
Where (first- or third-party) the purchase was made
final
- purchaseId → String
-
final
- reason → int
-
final
- reasonLabel → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionId → int
-
final
- transactionLineId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override