SubmitModerationReportRequest class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Properties
-
category
→ String
-
Valid values are the keys of the object
$.reportOptions[type] from GET /config. Descriptions of these are found at $.reportCategories[type].
final
-
contentId
→ String
-
The id of the user, group, world, avatar, inventory item, print, etc. being reported.
final
-
description
→ String?
-
The subjective reason for the report
final
-
details
→ SubmitModerationReportRequestDetails?
-
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
reason
→ String
-
Valid values are the strings in the array
$.reportOptions[type][category] from GET /config. Descriptions of these are found at $.reportReasons[type].
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ String
-
Valid values are the keys of the object
$.reportOptions from GET /config.
final