UpdatePropRequest class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
-
UpdatePropRequest({String? assetUrl, int? assetVersion, String? description, String? imageUrl, String? name, String? platform, String? propSignature, int? spawnType = 1, List<
String> ? tags, String? unityVersion, int? worldPlacementMask = 1}) - Returns a new UpdatePropRequest instance.
-
UpdatePropRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- assetUrl → String?
-
final
- assetVersion → int?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- imageUrl → String?
-
final
- name → String?
-
final
- platform → String?
-
This is normally
android,ios,standalonewindows,web, or the empty value ``, but also supposedly can be any random Unity version such as2019.2.4-801-Releaseor2019.2.2-772-Releaseor evenunknownplatform.final - propSignature → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spawnType → int?
-
How a prop is summoned and interacted with. 0: the prop fixed to some surface in the world 1: the prop is a pickup and may be held by users 2: ???
final
-
final
- unityVersion → String?
-
final
- worldPlacementMask → int?
-
Bitmask for restrictions on what world surfaces a prop may be summoned. 0: no restrictions 1: floors 2: walls 4: ceilings
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override